#
# spec file for package freerdp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500 && 0%{?is_opensuse}
%global _with_ffmpeg 1
#global _with_openh264 1
%global _with_soxr 1
%global _with_lame 1
%else
%if 0%{?sle_version} >= 150200 && 0%{?is_opensuse}
%global _with_ffmpeg 1
%endif
%endif

%global _with_gss 1

%define major_version 3
%define libfreerdp_package %{major_version}-%{major_version}
%define rdtk_version 0
%define rdtk_package %{rdtk_version}-%{rdtk_version}
%define uwac_version 0
%define uwac_package %{uwac_version}-%{uwac_version}

Name:           freerdp
Version:        3.5.1
Release:        1.2
Summary:        Remote Desktop Viewer Client
License:        Apache-2.0
Group:          Productivity/Networking/Other
URL:            https://www.freerdp.com/
Source0:        https://github.com/FreeRDP/FreeRDP/archive/%{version}.tar.gz#/FreeRDP-%{version}.tar.gz
Source1:        freerdp-rpmlintrc
BuildRequires:  chrpath
BuildRequires:  cmake >= 2.8
BuildRequires:  cups-devel
BuildRequires:  ed
BuildRequires:  fdupes
# doesn't compile correctly with older gcc's
%if 0%{?suse_version} <= 1600
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  libgsm-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(icu-i18n)
%{?_with_gss:BuildRequires:  pkgconfig(krb5) >= 1.13}
%{?_with_ffmpeg:
BuildRequires:  pkgconfig(libavcodec) >= 57.48.101
BuildRequires:  pkgconfig(libavutil)
}
BuildRequires:  pkgconfig(libcjson)
BuildRequires:  pkgconfig(libjpeg)
%{?_with_lame:BuildRequires:  pkgconfig(libmp3lame)}
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libpkcs11-helper-1)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libusb-1.0)
%{?_with_openh264:BuildRequires:  pkgconfig(openh264)}
BuildRequires:  pkgconfig(openssl)
%{?_with_soxr:BuildRequires:  pkgconfig(soxr)}
BuildRequires:  xmlto
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(zlib)
# force installation of latest library version
Requires:       lib%{name}%{libfreerdp_package} = %{version}-%{release}

%description
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the client
application.

%package sdl
Summary:        Remote Desktop Viewer Client
Group:          Productivity/Networking/Other

%description sdl
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the
sdl-based client application.

%package wayland
Summary:        Remote Desktop Viewer Client
Group:          Productivity/Networking/Other

%description wayland
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the
wayland-based client application.

%package server
Summary:        Remote Desktop Server
Group:          Productivity/Networking/Other

%description server
This package contains a server-side implementation which can export a desktop
via the Remote Desktop Protocol (RDP) following the Microsoft Open
Specifications.

%package proxy
Summary:        Remote Desktop Security and Monitorig Proxy Server
Group:          Productivity/Networking/Other

%description proxy
This package contains a proxy that allows to select specific features and
channels allowed for all connections passing through.
It allows monitoring of the running sessions.

%package -n %{name}-proxy-plugins
Summary:        Plugins for the Security and Monitorig Proxy Server
Group:          Productivity/Networking/Other
Requires:       %{name}-proxy = %{version}-%{release}

%description -n %{name}-proxy-plugins
This package contains the following plugins for the proxy server:
* bitmap-filter
* capture
* demo
* dyn-channel-dump

%package -n lib%{name}%{libfreerdp_package}
Summary:        Remote Desktop Viewer client library
Group:          System/Libraries

%description -n lib%{name}%{libfreerdp_package}
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the shared
libraries used by the client.

%package devel
Summary:        Development Files for freerdp
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{libfreerdp_package} = %{version}-%{release}
Requires:       lib%{name}-server-proxy%{libfreerdp_package}
Requires:       winpr-devel = %{version}-%{release}
Obsoletes:      %{name}-server-proxy%{libfreerdp_package}-devel < %{version}-%{release}
Provides:       %{name}-server-proxy%{libfreerdp_package}-devel = %{version}-%{release}

%description devel
This package contains development files necessary for developing applications
based on libfreerdp.

%package -n     libwinpr%{libfreerdp_package}
Summary:        Windows Portable Runtime
Group:          System/Libraries

%description -n libwinpr%{libfreerdp_package}
WinPR provides API compatibility for applications targeting non-Windows
environments. When on Windows, the original native API is being used instead of
the equivalent WinPR implementation, without having to modify the code using it.

%package -n winpr-devel
Summary:        Windows Portable Runtime development files
Group:          Development/Languages/C and C++
Requires:       cmake >= 2.8
# WinPRTargets-*.cmake defines targets for winpr-hash and winpr-makecert
Requires:       freerdp-server = %{version}-%{release}
Requires:       libwinpr%{libfreerdp_package} = %{version}-%{release}
Obsoletes:      libwinpr2-devel < %{version}-%{release}
Provides:       libwinpr2-devel = %{version}-%{release}

%description -n winpr-devel
This package contains header files for developing applications that
use the winpr and winpr-tools libraries.

%package -n     libuwac%{uwac_package}
Summary:        Use wayland as a client
Group:          System/Libraries

%description -n libuwac%{uwac_package}
Using wayland as a client (uwac) is a library to provide common
functionality for wayland clients.

%package -n uwac%{uwac_version}-devel
Summary:        Remote Desktop Toolkit libuwac development files
Group:          Development/Languages/C and C++
Requires:       cmake >= 2.8
Requires:       libuwac%{uwac_package} = %{version}-%{release}
Obsoletes:      libuwac%{uwac_version}-devel < %{version}-%{release}
Provides:       libuwac%{uwac_version}-devel = %{version}-%{release}
Obsoletes:      uwac%{uwac_version}-%{uwac_version}-devel < %{version}-%{release}
Provides:       uwac%{uwac_version}-%{uwac_version}-devel = %{version}-%{release}

%description -n uwac%{uwac_version}-devel
This package contains header files for developing applications that
use the uwac library.

%package -n librdtk%{rdtk_package}
Summary:        FreeRDP Toolkit
Group:          System/Libraries

%description -n librdtk%{rdtk_package}
This package contains the library for the Remote Desktop Toolkit.

%package -n rdtk%{rdtk_version}-devel
Summary:        FreeRDP Toolkit development files
Group:          Development/Languages/C and C++
Requires:       librdtk%{rdtk_package} = %{version}-%{release}

%description -n rdtk%{rdtk_version}-devel
This package contains the development files for RDTK.

%package -n lib%{name}-server-proxy%{libfreerdp_package}
Summary:        FreeRDP Server Proxy library
Group:          System/Libraries

%description -n lib%{name}-server-proxy%{libfreerdp_package}
This package contains the FreeRDP Server Proxy library files.

%prep
%autosetup -p1 -n FreeRDP-%{version}

%build
if [ -z "$SOURCE_DATE_EPOCH" ]; then
find . -type f -name "*.c" -exec perl -i -pe 's{__(DATE|TIME)__}{""}g' "{}" "+"
fi

%if 0%{?suse_version} <= 1600
export CXX=g++-12
%endif

%cmake \
        -DCMAKE_INSTALL_PREFIX=%{_prefix} \
        -DCMAKE_INSTALL_LIBDIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_EXE_LINKER_FLAGS="-pie" \
        -DCMAKE_SKIP_RPATH=TRUE \
        -DCMAKE_SKIP_INSTALL_RPATH=TRUE \
        -DWITH_ALSA=ON \
        -DWITH_CAIRO=ON \
        -DWITH_CUPS=ON \
        -DWITH_CHANNELS=ON -DBUILTIN_CHANNELS=OFF \
        -DWITH_PLUGIN_RPATH_ONLY=ON \
        -DWITH_CLIENT=ON \
        -DWITH_DIRECTFB=OFF \
        -DWITH_FFMPEG=%{?_with_ffmpeg:ON}%{?!_with_ffmpeg:OFF} \
        -DWITH_DSP_FFMPEG=%{?_with_ffmpeg:ON}%{?!_with_ffmpeg:OFF} \
        -DWITH_GSM=ON \
        -DWITH_GSSAPI=%{?_with_gss:ON}%{?!_with_gss:OFF} \
        -DWITH_GSTREAMER_1_0=ON -DWITH_GSTREAMER_0_10=OFF \
        -DWITH_ICU=ON \
        -DWITH_IPP=OFF \
        -DWITH_JPEG=ON \
        -DWITH_LAME=%{?_with_lame:ON}%{?!_with_lame:OFF} \
        -DWITH_MANPAGES=ON \
        -DWITH_OPENH264=%{?_with_openh264:ON}%{?!_with_openh264:OFF} \
        -DWITH_OPENSSL=ON \
        -DWITH_PCSC=ON \
        -DWITH_PULSE=ON \
        -DWITH_SERVER=ON \
        -DWITH_SERVER_INTERFACE=ON \
        -DWITH_SHADOW_X11=ON \
        -DWITH_SHADOW_MAC=ON \
        -DWITH_SAMPLE=OFF \
        -DWITH_SOXR=%{?_with_soxr:ON}%{?!_with_soxr:OFF} \
        -DWITH_WAYLAND=ON \
        -DWITH_X11=ON \
        -DWITH_XCURSOR=ON \
        -DWITH_XEXT=ON \
        -DWITH_XKBFILE=ON \
        -DWITH_XI=ON \
        -DWITH_XINERAMA=ON \
        -DWITH_XRENDER=ON \
        -DWITH_XTEST=ON \
        -DWITH_XV=ON \
        -DWITH_ZLIB=ON \
%ifarch x86_64
        -DWITH_SSE2=ON \
%else
        -DWITH_SSE2=OFF \
%endif
%ifarch armv7hl
        -DARM_FP_ABI=hard \
        -DWITH_NEON=OFF \
%endif
%ifarch armv7hnl
        -DARM_FP_ABI=hard \
        -DWITH_NEON=ON \
%endif
%ifarch armv5tel armv6l armv7l
        -DARM_FP_ABI=soft \
        -DWITH_NEON=OFF \
%endif
        -DCHANNEL_GEOMETRY=ON -DCHANNEL_GEOMETRY_CLIENT=ON \
        -DCHANNEL_URBDRC=ON \
        -DCHANNEL_URBDRC_CLIENT=ON

%make_build

%install
cd build
%make_install
%fdupes %{buildroot}%{_libdir}/cmake/

%ldconfig_scriptlets -n lib%{name}%{libfreerdp_package}
%ldconfig_scriptlets -n libwinpr%{libfreerdp_package}
%ldconfig_scriptlets -n libuwac%{uwac_package}
%ldconfig_scriptlets -n librdtk%{rdtk_package}
%ldconfig_scriptlets -n lib%{name}-server-proxy%{libfreerdp_package}

%files
%{_bindir}/x%{name}
%{_mandir}/man1/x%{name}.1%{?ext_man}
%{_mandir}/man7/wlog.7%{?ext_man}

%files sdl
%{_bindir}/sdl-%{name}
%{_mandir}/man1/sdl-freerdp.1%{?ext_man}


%files wayland
%{_bindir}/wl%{name}
%{_mandir}/man1/wl%{name}.1%{?ext_man}

%files server
%{_bindir}/%{name}-shadow-cli
%{_bindir}/winpr-hash
%{_bindir}/winpr-makecert
%{_mandir}/man1/%{name}-shadow-cli.1%{?ext_man}
%{_mandir}/man1/winpr-hash.1%{?ext_man}
%{_mandir}/man1/winpr-makecert.1%{?ext_man}

%files proxy
%{_bindir}/%{name}-proxy
%{_mandir}/man1/freerdp-proxy.1%{?ext_man}

%files -n %{name}-proxy-plugins
%dir %{_libdir}/%{name}%{major_version}
%dir %{_libdir}/%{name}%{major_version}/proxy
%{_libdir}/%{name}%{major_version}/proxy/proxy-bitmap-filter-plugin.so
%{_libdir}/%{name}%{major_version}/proxy/proxy-demo-plugin.so
%{_libdir}/%{name}%{major_version}/proxy/proxy-dyn-channel-dump-plugin.so

%files -n lib%{name}%{libfreerdp_package}
%license LICENSE
%{_libdir}/lib%{name}%{major_version}.so.*
%{_libdir}/lib%{name}-client%{major_version}.so.*
%{_libdir}/lib%{name}-shadow%{major_version}.so.*
%{_libdir}/lib%{name}-server%{major_version}.so.*
%{_libdir}/lib%{name}-shadow-subsystem%{major_version}.so.*

%files devel
%dir %{_libdir}/cmake/FreeRDP-Proxy3
%dir %{_libdir}/cmake/WinPR-tools3
%{_libdir}/cmake/FreeRDP%{major_version}
%{_libdir}/cmake/FreeRDP-Client%{major_version}
%{_libdir}/cmake/FreeRDP-Server%{major_version}
%{_libdir}/cmake/FreeRDP-Shadow%{major_version}
%{_libdir}/cmake/FreeRDP-Proxy%{major_version}/FreeRDP-ProxyConfig.cmake
%{_libdir}/cmake/FreeRDP-Proxy%{major_version}/FreeRDP-ProxyConfigVersion.cmake
%{_libdir}/cmake/FreeRDP-Proxy%{major_version}/FreeRDP-ProxyTargets-relwithdebinfo.cmake
%{_libdir}/cmake/FreeRDP-Proxy%{major_version}/FreeRDP-ProxyTargets.cmake
%{_libdir}/cmake/WinPR-tools%{major_version}/WinPR-toolsConfig.cmake
%{_libdir}/cmake/WinPR-tools%{major_version}/WinPR-toolsConfigVersion.cmake
%{_libdir}/cmake/WinPR-tools%{major_version}/WinPR-toolsTargets-relwithdebinfo.cmake
%{_libdir}/cmake/WinPR-tools%{major_version}/WinPR-toolsTargets.cmake
%{_includedir}/%{name}%{major_version}
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-client%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-server%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-shadow%{major_version}.pc
%{_libdir}/pkgconfig/%{name}-server-proxy%{major_version}.pc

%files -n libwinpr%{libfreerdp_package}
%license LICENSE
%{_libdir}/libwinpr%{major_version}.so.*
%{_libdir}/libwinpr-tools%{major_version}.so.*

%files -n winpr-devel
%{_libdir}/cmake/WinPR%{major_version}
%{_includedir}/winpr%{major_version}
%{_libdir}/libwinpr%{major_version}.so
%{_libdir}/libwinpr-tools%{major_version}.so
%{_libdir}/pkgconfig/winpr%{major_version}.pc
%{_libdir}/pkgconfig/winpr-tools%{major_version}.pc

%files -n libuwac%{uwac_package}
%license LICENSE
%{_libdir}/libuwac%{uwac_version}.so.*

%files -n uwac%{uwac_version}-devel
%{_libdir}/cmake/uwac%{uwac_version}
%{_includedir}/uwac%{uwac_version}
%{_libdir}/libuwac%{uwac_version}.so
%{_libdir}/pkgconfig/uwac%{uwac_version}.pc

%files -n librdtk%{rdtk_package}
%{_libdir}/librdtk%{rdtk_version}.so.*

%files -n rdtk%{rdtk_version}-devel
%{_libdir}/cmake/rdtk%{rdtk_version}
%{_includedir}/rdtk%{rdtk_version}
%{_libdir}/librdtk%{rdtk_version}.so
%{_libdir}/pkgconfig/rdtk%{rdtk_version}.pc

%files -n lib%{name}-server-proxy%{libfreerdp_package}
%{_libdir}/libfreerdp-server-proxy%{major_version}.so.*

%changelog
* Wed Apr 24 2024 ecsos <ecsos@opensuse.org>
- Update to 3.5.1:
  * Lots of fixes for oss-fuzz reports
  * Timezone detection fixes (#10106)
  * SDL key remapping support (#10103)
  * Improved help (#10099)
  * FreeBSD epoll detection fix (#10097)
- Changes from 3.5.0:
  * CVE:
  - CVE-2024-32041 [Low[ OutOfBound Read in zgfx_decompress_segment
  - CVE-2024-32039 [Moderate] Integer overflow & OutOfBound Write in clear_decompress_residual_data
  - CVE-2024-32040 [Low] integer underflow in nsc_rle_decode
  - CVE-2024-32458 [Low] OutOfBound Read in planar_skip_plane_rle
  - CVE-2024-32459 [Low] OutOfBound Read in ncrush_decompress
  - CVE-2024-32460 [Low] OutOfBound Read in interleaved_decompress
  * location channel support #9981, #9984, #10065
  * bugfixes for report from Evgeny Legerov of Kaspersky Lab #10077
  * fuzzer tests from Evgeny Legerov of Kaspersky Lab #10078
  * bugfixes for coverty scanner #10066, #10068,  #10069, #10070, #10075
  * clipboard and generic locking fixes #10076
  * split autoreconnect support from enabling it #10063
  * various nightly and workflow fixes #10064, #10058, #10062
  * always set wm-class to app_id #10051
  * refactored and simplified CMake #10046, #10047
  * fix relative mouse event sending #10010
  * improve and unify check for APIs used (POSIX, win32, mac, ...) #9995
  * fix termination for gateway connections #9985
  * fix drivestoredirect RDP file setting, ignore invalid #9989
  * drop IPP support #10038
* Tue Mar 26 2024 Jan Engelhardt <jengelh@inai.de>
- Trim duplicate version number from package names; rename
  uwac0-0-devel -> uwac0-devel, rdtk0-0-devel -> rdtk0-devel.
- RPM groups updated.
* Tue Mar 26 2024 Joan Torres <joan.torres@suse.com>
- Drop conflicts with freerdp2:
  * The freerdp2 package doesn't conflict with any freerdp3 package
  * Now both can be installed simultaneously
* Tue Mar 19 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.4.0:
  * fix a bug in RAIL mode not activating window focus (#9973)
  * improve logging (#9969, #9943)
  * OpenSSL <= 1.1.1 build fixes (#9897)
  * improved help (#9899, #9905)
  * improved MINGW support (#9914, #9915, #9919, #9964, #9965, #9920)
  * fix right control ungrab for xfreerdp (#9960)
  * fix RPATH option settings (#9963)
  * fix SDL client screen updates (#9962, #9954)
  * fix issues with childSession under windows (#9961, #9956, #9922)
  * fix xfreerdp crash with +auth-only (#9947)
  * fix windows printer channel (#9934)
  * add support to enforce gateway policy (#9942)
  * improve big endian support (#9927)
  * ignore empty proxy environment variables (#9929)
  * improve quoting support for command line (#9912)
  * Improved image clipboard (xfreerdp, wlfreerdp) (#9873, #9826)
  * Improved SDL client (#9875, #9887, #9883, #9878, #9792)
  * Allow plugin loader to only use absolute paths (#9809)
  * Improved TLS channel binding (#9838)
  * Add GCC/clang attribute malloc wrapper WINPR_ATTR_MALLOC (#9863)
  * Major clang-tidy code cleanups and bugfixes (#9799, #9834)
  * Provide some defaults for wObject functions (#9799)
  * Fix a bug in shadow with GFX breaking mstsc (#9818)
  * Improved manpages and help (#9813, #9804)
  * Blocking mode via transport IO interface (#9793)
* Fri Jan 19 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.2.0:
  * Fix proxy module load check (#9777)
  * Improve kerberos error logging (#9771)
  * Add option to run client dynamic channel synchronous (#9764)
  * Move huge struct to heap (#9763)
  * Improved failure logging of license module (#9759)
  * Improve server side gfx logging (#9757)
  * Print shadow server help with printf instead of WLog (#9756)
  * Fix SDL client timer initialization (#9754)
  * Fix server peer message parsing (#9751)
  * Enable NEON instructions if __ARM_NEON is defined (#9748)
  * Add new proxy config file option TlsSecLevel (#9741)
  * Improve android and mac os build scripts (#9735)
  * Do not disable wayland support on BSD (#9730)
  * Fix issues with assistance file parsing (#9727, #9728)
  * Keyboard handling fixes for wayland client (#9725)
  * Fix relative pkg-config file paths (#9720)
  * Add new transport IO callback GetPublicKey (#9719)
  * Fix wayland client scaling (#9715)
* Sat Jan  6 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.0:
  * Fix a nasty bug with relative mouse movement (#9677)
  * LibreSSL support enhancements (#9691, #9670)
  * mbedTLS support enhancements (#9662)
  * New and improved manpages (#9690, #9650)
  * Unify CMake common options, add (optional) binary versioning and allow
  * building rdtk and uwac as static dependencies (#9695)
  * SDL client improvements (#9693, #9657, #9659, #9683, #9680, #9657, #9664, #9656)
* Tue Dec 19 2023 Hans-Peter Jansen <hpj@urpla.net>
- Remove freerdp-allow-compiling-with-old-c++-compiler.patch
  Solve by requiring gcc12-c++ for older environments
- Adjust Requires/Obsoletes
- Merge %%{name}-server-proxy%%{libfreerdp_package}-devel with -devel
* Mon Dec 18 2023 Joan Torres <joan.torres@suse.com>
- Add freerdp-allow-compiling-with-old-c++-compiler.patch
  * This allows building with older Leap versions which use gcc7-c++.
- Use cups-devel instead of relying on pkgconfig.
  * Older Leap versions were unable to find it that way.
- Fix some package naming and versioning.
* Fri Dec 15 2023 Joan Torres <joan.torres@suse.com>
- Add sdl dependencies to build the sdl-freerdp client.
  * This is due to the wlfreerdp client being deprecated.
- Cleanup specfile.
  * Rely preferably on pkgconfig to pull devel packages instead of
    hardcoding them.
* Thu Dec 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.0:
  * Support for AAD/AVD authentication
  * Support for websocket transport
  * Support smartcard authentication (TLS and NLA)
  * Full smartcard emulation support (login with certificate + key)
  * Rewritten proxy, new module API
  * New reference client based on SDL2 (work in progress)
  * Rewritten logging, now parsing issues are all writing to the log so
    that issues with protocol incompatibilities can be easier analyzed
    by just turning on logging
  * Full OpenSSL 3 support
  * Internal implementations for RC4, MD4 and MD5 (required for non critical
    parts in RDP but not part of more recend SSL libraries)
  * Updated RDP protocol support
  * Improved xfreerdp remote app support
  * Reworked internal state machine for both client and server implementations
  * Server implementations can now make use of connect-time network autodetection
  * Improved clipboard handling, now also support server-to-client file transfer
    (currently xfreerdp only)
  * EnhancedRemoteApp support: Utilizing the more modern standard allows remote
    apps with less glitches and window shadows
  * Added client- and server-side handling for RDSTLS
  * Support for the graphics redirection channel
  * Full changelongs can be found at the following links:
    + https://github.com/FreeRDP/FreeRDP/releases/tag/3.0.0-beta1
    + https://github.com/FreeRDP/FreeRDP/releases/tag/3.0.0-beta2
    + https://github.com/FreeRDP/FreeRDP/releases/tag/3.0.0-beta3
    + https://github.com/FreeRDP/FreeRDP/releases/tag/3.0.0-beta4
    + https://github.com/FreeRDP/FreeRDP/releases/tag/3.0.0-rc0
    + https://github.com/FreeRDP/FreeRDP/releases/tag/3.0.0
- Security fix:
  - CVE-2023-40574, bsc#1214869
  - CVE-2023-40575, bsc#1214870
  - CVE-2023-40576, bsc#1214871
- Drop upstreamed 0001-Make-H.264-codec-optional-during-runtime.patch.
- Enable GSS again since gh#issues/4348 has been fixed.
* Thu Nov 16 2023 Christophe Marin <christophe@krop.fr>
- Fix winpr-devel dependencies. WinePRTargets-*.cmake defines
  CMake targets for winpr-hash and winpr-makecert. They have to be
  present.
* Fri Oct 20 2023 Adriankhl <dlshcbmuipmam@hotmail.com>
- Update to 2.11.2
  * Backported #9356: Fix issues with order updates
  * Backported #9378: backported wArrayList (optional) copy on insert
  * Backported #9360: backported certificate algorithm detection
* Wed Aug 30 2023 Christophe Marin <christophe@krop.fr>
- Update to 2.11.0
  * Various input validation fixes
  * Added various CMake options #9317
  * LibreSSL build fixes #8709
  * Big endian support
  * Mouse grabbing support
  * wayland scrolling fix
  * Update h264 to use new FFMPEG API
  * early bail from update_read_window_state_order breaks protocol
  * rdpecam/server: Remove wrong assertion
  * bounds checks for gdi/gfx rectangles
  * enforce rdpdr client side state checks
  * deactivate mouse grabbing by default
  * channels/cliprdr: Fix writing incorrect PDU type for unlock
    PDUs
  * Fix CVE-2023-39350 - boo#1214856
    incorrect offset calculation leading to DoS
  * Fix CVE-2023-39351 - boo#1214857
    Null Pointer Dereference leading DoS in RemoteFX
  * Fix CVE-2023-39352 - boo#1214858
    Invalid offset validation leading to Out Of Bound Write
  * Fix CVE-2023-39353 - boo#1214859
    Missing offset validation leading to Out Of Bound Read
  * Fix CVE-2023-39354 - boo#1214860
    Out-Of-Bounds Read in nsc_rle_decompress_data
  * Fix CVE-2023-39356 - boo#1214862
    Missing offset validation leading to Out-of-Bounds Read in gdi_multi_opaque_rect
  * Fix CVE-2023-40181 - boo#1214863
    Integer-Underflow leading to Out-Of-Bound Read in zgfx_decompress_segment
  * Fix CVE-2023-40186 - boo#1214864
    IntegerOverflow leading to Out-Of-Bound Write Vulnerability in gdi_CreateSurface
  * Fix CVE-2023-40188 - boo#1214866
    Out-Of-Bounds Read in general_LumaToYUV444
  * Fix CVE-2023-40567 - boo#1214867
    Out-Of-Bounds Write in clear_decompress_bands_data
  * Fix CVE-2023-40569 - boo#1214868
    Out-Of-Bounds Write in progressive_decompress
  * Fix CVE-2023-40589 - boo#1214872
    Global-Buffer-Overflow in ncrush_decompress
- Drop patch, now upstream:
  * Update_h264_to_use_new_FFMPEG_API.patch
* Wed May 31 2023 Andreas Schwab <schwab@suse.de>
- Don't compile shared objects with -fPIE and use -pie only for executables
- Reenable LTO on ARM
* Mon Apr 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add Update_h264_to_use_new_FFMPEG_API.patch: Update h264 to use
  new FFMPEG API.
* Thu Feb 16 2023 Hans-Peter Jansen <hpj@urpla.net>
- Ugraded to freerdp 2.10.0
  * Fix android build scripts, use CMake from SDK
  * Fix connection negotiation with mstsc/msrdc #8426
  * [ntlm]: use rfc5929 binding hash algorithm #8430
  * [channels,printer] Fixed reference counting #8433
  * Fix uwac pixman #8439
  * Fix Rdp security #8457
  * [client,x11] Detect key autorepeat #8522
  * [build] add channel path to RPATH #8551
  * Fix build with BUILTIN_CHANNELS=OFF #8560
  * revert changes so that the osmajortype/osminortype is not
    overwritten #8571
  * [uwac] do not use iso C functions #8604
  * [winpr,sam] fix inalid NULL arguments #8605
  * Fix incompatible function pointer types #8625
  * Fixed issues:
  * Backported #8581: Ignore data PDUs for DVCs that were not
    opened successfully
  * Backported #8498: [channel,urbdrc] fix type of usb hotplug
    callback
  * Backported #8537: Extended info enforce limits
  * Backported #8611: [core] add missing redirection fields
- Patches removed, that were accepted upstream
  + freerdp-builtin-channels-off-link-fix.diff
  + freerdp-fix-rpath-settings.diff
* Fri Dec 16 2022 Hans-Peter Jansen <hpj@urpla.net>
- Complement fix for -DBUILTIN_CHANNELS=OFF to fix freerdp-proxy
  accessing librdpgfx-client.so: freerdp-fix-rpath-settings.diff
  Fixes second part of bnc#1205595.
* Sun Dec 11 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Disable VAAPI feature due bug https://bugzilla.opensuse.org/show_bug.cgi?id=1205595
* Thu Nov 17 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Ugraded to freerdp 2.9.0
  * Backported #gh:FreeRDP/FreeRDP#8252: Support sending server redirection PDU
  * Backported #gh:FreeRDP/FreeRDP#8406: Ensure X11 client cursor is never
    smaller 1x1
  * Backported #gh:FreeRDP/FreeRDP#8403: Fixed multiple client side input
    validation issues - boo#1205512, boo#1205563, boo#1205564
    (CVE-2022-39316, CVE-2022-39317, CVE-2022-39318, CVE-2022-39319,
    CVE-2022-39320, CVE-2022-41877, CVE-2022-39347)
  * Backported #7282: Proxy server now discards input events sent before
    activation was received
  * Backported #gh:FreeRDP/FreeRDP#8324: Internal replacements for md4,
    md5 and hmac-md5
    For the time being the RDP protocol requires these outdated hash
    algorithms. So any distribution that wants to ship a working
    FreeRDP should check the options WITH_INTERNAL_MD4 (and depending
    on OpenSSL deprecation status WITH_INTERNAL_MD5)
- Fixed issues:
  * Backported #gh:FreeRDP/FreeRDP#8341: Null checks in winpr_Digest_Free
  * Backported #gh:FreeRDP/FreeRDP#8335: Missing NULL return
    in winpr_Digest_New
  * Backported #gh:FreeRDP/FreeRDP#8192: Support for audin
    version 2 microphone channel
  * Backported #gh:FreeRDP/FreeRDP#7282: Discard input events before
    activation (Fixes #8374)
* Mon Nov  7 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Ugraded to freerdp 2.8.1
  * Fixed CVE-2022-39282 - boo#1204258
    using the `/parallel` command line switch might read uninitialized data
  * Fixed CVE-2022-39283 - boo#1204257
    using the `/video` command line switch might read uninitialized data
  * Added missing commit for backported #gh:FreeRDP/FreeRDP#8041:
    Remove ALAW/ULAW codecs from linux backends (unreliable)
  * Added hash checks for android build script dependencies
- Fixed issues:
  * #gh:FreeRDP/FreeRDP#8190: Fix build break with newer FFMPEG versions
  * #gh:FreeRDP/FreeRDP#8234: Updated flatpak with build script
  * #gh:FreeRDP/FreeRDP#8210: Better execinfo support check for android
  * #gh:FreeRDP/FreeRDP#7708: Header now defines DumpThreadHandles
  * #gh:FreeRDP/FreeRDP#8176: Check fullscreen state and not setting
  * #gh:FreeRDP/FreeRDP#8236: Send resize on window state change
  * #gh:FreeRDP/FreeRDP#7611: Audin macOS monterey fix
  * #gh:FreeRDP/FreeRDP#8291: Android build script update
  * Fix length checks and initialization in the deprecated
    (disabled per default) tsmf channel
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Ugraded to freerdp 2.8.0
  * Backported API to get peer accepted channel option flags
  * Backported API to get peer accepted channel names
  * Backported Stream_CheckAndLogRequiredLength
  * Backported #7954: Add server side handling for [MS-RDPET]
  * Backported #8010: Add server side handling for [MS-RDPECAM]
  * Backported #8041: Remove ALAW/ULAW codecs from linux backends (unreliable)
  * Backported #8051: Relieve CLIPRDR filename restriction when connecting to non-MS Windows servers
  * Backported #8048: TLS version control
  * Backported #7987: Add a new command line arg to enforce tls1.2
- Fixed issues:
  * Fixed #7837: Prevent out of bound reads for FFMPEG
  * Backported #7859 and #7861: Unwind support for backtrace generation
  * Backported #7440: wlfreerdp appid
  * Backported #7832: RAIL window restore
  * Backported #7833: Refactored WinPR thread locking
  * Backported #7893: Mac rdpsnd memory leak fixes
  * Backported #7895: Mac audin memory leak fixes
  * Backported #7898: Automatic android versioning
  * Backported #7916: GFX 10.7 capability support
  * Backported #7949: Server RDPSND API improvements
  * Backported #7957: Server DVC API improvements
  * Backported #7760: Fixed osMinorType values
  * Backported #8013: Add missing osMajorType values
  * Backported #8076: Fix wrong usage of subband diffing flag (tile artifact fix)
* Tue Apr 26 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to freerdp 2.7.0
  * OpenSSL3 gateway support (#gh:FreeRDP/FreeRDP#7822)
  * various NTLM fixes
  * WINPR_ASSERT to ease future backports
  * Fixed CVE-2022-24882 - boo#1198919
    NTLM not properly check parameters
  * Fixed CVE-2022-24883 - boo#1198921
    Fix authentication against invalid SAM files
- Fixed issues:
  * #gh:FreeRDP/FreeRDP#6786: Use /network:auto by default
  * #gh:FreeRDP/FreeRDP#7714: Workaround for broken surface frame marker
  * #gh:FreeRDP/FreeRDP#7733: Support 10bit X11 color (BGRX32 only)
  * #gh:FreeRDP/FreeRDP#7745: GFX progressive double free
  * #gh:FreeRDP/FreeRDP#7808: Disable websockets with /gt:rpc
  * #gh:FreeRDP/FreeRDP#7815: RAIL expect LOGON_MSG_SESSION_CONTINUE
* Tue Mar  8 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to freerdp 2.6.1
  * Decreased logging verbosity, now freerdp is much less verbose by default
  * Backported freerdp_abort_connect during freerdp_connect fix (#gh:FreeRDP/FreeRDP#7700)
  * Backported improved version dection see docs/version_detection.md for details
  * Backported various rdpsnd fixes (#gh:FreeRDP/FreeRDP#7695)
* Wed Feb 23 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to freerdp 2.6.0
  * Backported android FFMPEG build scripts
  * Updated android build dependencies
  * Backported AINPUT channel
  Fixed issues:
  * Backported #gh:FreeRDP/FreeRDP#7303: Fix PDU length for RDPINPUT_PROTOCOL_V300
  * Backported #gh:FreeRDP/FreeRDP#7658: Sanitize optional physical monitor size values
  * Backported #gh:FreeRDP/FreeRDP#7426: Wayland memory corruption
  * Backported #gh:FreeRDP/FreeRDP#7293: Remove unused codec x264
  * Backported #gh:FreeRDP/FreeRDP#7541: Allow resolutions larger 2048x2048
  * Backported #gh:FreeRDP/FreeRDP#7574: FFMPEG 5.0 support
  * Backported #gh:FreeRDP/FreeRDP#7578: FFMPEG 5.0 support
  * Backported #gh:FreeRDP/FreeRDP#7580: Fixed device hotplugging
  * Backported #gh:FreeRDP/FreeRDP#7583: GetUserNameExA: Prefer getpwuid_r over getlogin_r over getlogin
  * Backported #gh:FreeRDP/FreeRDP#7585: Android Mediacodec support
* Mon Jan 24 2022 Predrag Ivanović <predivan@mts.rs>
- Enable FFmpeg support for Leap-15.2+
* Thu Jan 13 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to freerdp 2.5.0
  * Fixed smartcard login in case a redirection occurs the pin was lost
  * Backported windows client drawing fixes
  * Backported improved macOS keyboard layout detection
  * Backported TcpConnectTimeout
  * Backported LibreSSL compatibility patches
  * Backported signal handler backtrace
  * Backported OpenSSL 3.0 support
  * Backport #gh:FreeRDP/FreeRDP#7539: Wayland client clipboard issues
  * Backport #gh:FreeRDP/FreeRDP#7509: Various fixes regarding registry
    emulation, addin loader and updated locale detection
  * Backport #gh:FreeRDP/FreeRDP#7466: Android android_register_pointer
    missing initialization
* Thu Dec  2 2021 Fabian Vogt <fvogt@suse.com>
- Add patch to fix connecting without H.264-enabled FFmpeg (boo#1190823):
  * 0001-Make-H.264-codec-optional-during-runtime.patch
- Use %%autosetup
* Thu Oct 21 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to freerdp 2.4.1
  Important security issues, boo#1191895:
  * CVE-2021-41159: Improper client input validation for gateway connections allows to overwrite memory
  * CVE-2021-41160: Improper region checks in all clients allow out of bound write to memory
  Noteworthy changes:
  * Refactored RPC gateway parsing code
  * OpenSSL 3.0 compatibility fixes
  * USB redirection: fixed transfer lengths
  Fixed issues:
  * #gh:FreeRDP/FreeRDP#7363: Length checks in ConvertUTF8toUTF16
  * #gh:FreeRDP/FreeRDP#7349: Added checks for bitmap width and heigth values
- Force library update to the latest, renamed versions (followup to
  boo#1191755)
* Wed Oct 20 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Renamed libraries to follow packaging standards as requested in
  boo#1191755
* Thu Oct  7 2021 Hans-Peter Jansen <hpj@urpla.net>
- Finally nailed it: CMAKE_INSTALL_LIBDIR is absolute on Leaps and
  relative on TW, but freerdp requires the relative variant.
  Fixes boo#1190919
* Wed Oct  6 2021 Hans-Peter Jansen <hpj@urpla.net>
- Remove freerdp-fix-plugin-path.patch again, the problem was
  introduced/fixed by cmake changes
* Sat Sep 18 2021 Hans-Peter Jansen <hpj@urpla.net>
- Create an explicit freerdp dependency for libwinpr
* Fri Sep 17 2021 Hans-Peter Jansen <hpj@urpla.net>
- Add preliminary patch freerdp-fix-plugin-path.patch to fix dynamic
  addin loading
* Fri Sep 17 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Modified spec to satisfy because obs-service-source_validator does not
  support elif
* Wed Sep 15 2021 Hans-Peter Jansen <hpj@urpla.net>
- Fix the spec-cleaner mess
- Enable a few options on TW
- Build for 15.3 required another lib
- Remove X264 option, no related backend exists and enabling it fails
  in cmake creation stage
* Fri Aug 20 2021 Hans-Peter Jansen <hpj@urpla.net>
- Reorganize build flags
- Apply fix for -DBUILTIN_CHANNELS=OFF: freerdp-builtin-channels-off-link-fix.diff
- Add plugins to libwinpr
* Wed Aug 11 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.4.0
  Noteworthy changes:
  * Backported multithreaded progressive decoder (#7036)
  * Backported clipboard fixes (#6924)
  * Fixed remote file read (#7185)
  Fixed issues:
  * #gh:FreeRDP/FreeRDP#6938: RAILS clipboard remote -> local
  * #gh:FreeRDP/FreeRDP#6985: Support newer FFMPEG builds
  * #gh:FreeRDP/FreeRDP#6989: Use OpenSSL default certificate store settings
  * #gh:FreeRDP/FreeRDP#7073: Planar alignment fixes
* Mon Mar 15 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.3.2
  Noteworthy changes:
  * Fixed autoreconnect printer backend loading
  * Fixed compilation on older mac os versions < 10.14
  * Fixed mouse pointer move with smart-sizing
  * Added command line option to disable websocket gateway support
  * Fixed drive hotplugging issues with windows
  * Fixed smartcard issues on mac
  Fixed issues:
  * #gh:FreeRDP/FreeRDP#6900: Transparency issues with aFreeRDP
  * #gh:FreeRDP/FreeRDP#6848: Invalid format string in smartcard trace
  * #gh:FreeRDP/FreeRDP#6846: Fixed static builds
  * #gh:FreeRDP/FreeRDP#6888: Crash due to missing bounds checks
  * #gh:FreeRDP/FreeRDP#6882: Use default sound device on mac
* Mon Mar  1 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.3.1
  Noteworthy changes:
  * This is a compatibility bugfix release readding some (deprecated)
    symbols/defines
  * Also add some more EXPERIMENTAL warnings to CMake flags as some were not
    clear enough.
  * Fixed a memory leak in xfreerdp (mouse pointer updates)
  * No longer activating some compile time debug options with
  - DWITH_DEBUG_ALL=ON which might leak sensitive information.
  * Added -DDEFINE_NO_DEPRECATED for developers to detect use of
    deprecated symbols
* Thu Feb 25 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.3.0
  Noteworthy changes:
  * Websocket support for proxy connections
  * Progressive codec improvements. Reduces graphical glitches against windows
    and ogon servers
  * Fixed +glyph-cache, now working properly without disconnects
  * Huge file support in clipboard
  * XWayland support for xfreerdp (keyboard grabbing)
  * Improved wlfreerdp (wayland client)
  * Option to allow keyboard scancodes to be remapped manually
  * Improved mouse wheel behaviour when scrolling
  * Improved dynamic channel behaviour, more stable event detection
  * New connection state PubSub notification: Clients can now monitor current
    connection state
  Fixes:
  * gh#FreeRDP/FreeRDP/6626: Fixed parsing of FastGlyph order.
    gh#FreeRDP/FreeRDP/6624: Added support for xwayland keyboard grab
    gh#FreeRDP/FreeRDP/6492: Added clipboard CB_HUGE_FILE_SUPPORT_ENABLED flag
    gh#FreeRDP/FreeRDP/6428: Improve NLA error code logging.
    gh#FreeRDP/FreeRDP/6416: Http gateway message support
    gh#FreeRDP/FreeRDP/6753: List of pull requests to backport for stable-next
- Added freerdp-rpmlintrc to supress a false positive as gethostbyname() is
  a windows-function call not a unix one.
* Mon Jul 20 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.2.0 (boo#1174321, gh#FreeRDP/FreeRDP#6381)
  * SECURITY: CVE-2020-15103 - Integer overflow due to missing input sanitation in rdpegfx channel
  * Sound & mic - filter GSM codec for microphone redirection (gh#FreeRDP/FreeRDP#6263)
  * windows client title length (gh#FreeRDP/FreeRDP#6335)
  * "Alternate Secondary Drawing Order UNKNOWN" (gh#FreeRDP/FreeRDP#6370)
  * remoteapp with dialog is disconnecting when it loses focus (gh#FreeRDP/FreeRDP#6298)
  * v2.1.2: Can't connect to Windows7 (gh#FreeRDP/FreeRDP#6299)
  * fix: memory leak in nsc
  * urbdrc: some fixes and improvements
  * build: use cmake to detect getlogin_r, improve asan checks/detection
  * server/proxy:
  - new: support for heartbeats
  - new: support for rail handshake ex flags
  - fix: possible race condition with redirects
  * Drop upstream fixed patch: freerdp-CVE-2020-15103.patch
- Removed freerdp_Mask_CACHED_BRUSH_when_checking_brush_style.patch
* Fri Jul 17 2020 QK ZHU <qkzhu@suse.com>
- Drop BuildRequires of libavcodec for Leap/SLE (bsc#1174200)
* Thu Jul  2 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added freerdp_Mask_CACHED_BRUSH_when_checking_brush_style.patch
  which fixed frequent crashes described in boo#1173605 and gh#FreeRDP/FreeRDP#6298
* Mon Jun 22 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.1.2 (boo#1173247)
  * CVE-2020-4033 Out of bound read in RLEDECOMPRESS
  * CVE-2020-4031 Use-After-Free in gdi_SelectObject
  * CVE-2020-4032 Integer casting vulnerability in `update_recv_secondary_order`
  * CVE-2020-4030 OOB read in `TrioParse`
  * CVE-2020-11099 OOB Read in license_read_new_or_upgrade_license_packet
  * CVE-2020-11098 Out-of-bound read in glyph_cache_put
  * CVE-2020-11097 OOB read in ntlm_av_pair_get
  * CVE-2020-11095 Global OOB read in update_recv_primary_order
  * CVE-2020-11096 Global OOB read in update_read_cache_bitmap_v3_order
  * Gateway RPC fixes for windows
  * Fixed resource fee race resulting in double free in USB redirection
  * Fixed wayland client crashes
  * Fixed X11 client mouse mapping issues (X11 mapping on/off)
  * Some proxy related improvements (capture module)
  * Code cleanup (use getlogin_r, ...)
- Removed obsolete upstream patch freerdp-bug-6205.patch
* Wed May 20 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.1.1 (boo#1171441)
  * CVE-2020-13396: GHSL-2020-100 OOB Read in ntlm_read_ChallengeMessage
  * CVE-2020-13397: GHSL-2020-101 OOB Read in security_fips_decrypt due to uninitialized value
  * CVE-2020-13398: GHSL-2020-102 OOB Write in crypto_rsa_common
  * Enforce synchronous legacy RDP encryption count (#6156)
  * Fixed some leaks and crashes missed in 2.1.0
  * Removed dynamic channel listener limits
  * Lots of resource cleanup fixes (clang sanitizers)
  * A couple of performance improvements
  * Various small annoyances eliminated (typos, prefilled username for windows client, ...)
- Removed freerdp-bug-6175.patch and freerdp-bug-6207.patch because included in upstream
* Wed May 20 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added freerdp-bug-6205.patch to fix reading newline on certificate accept gh#FreeRDP/FreeRDP#6205
- Added freerdp-bug-6175.patch to fix Certificate Checking Recently Broke gh#FreeRDP/FreeRDP#6148
- Added freerdp-bug-6207.patch to fix Abort on first possible certificate validation error gh#FreeRDP/FreeRDP#6207
* Fri May  8 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to release 2.1.0 (boo#1171441)
  * Fixed CVEs:
  - CVE-2020-11039
  - CVE-2020-11038
  - CVE-2020-11043
  - CVE-2020-11040
  - CVE-2020-11041
  - CVE-2020-11019
  - CVE-2020-11017
  - CVE-2020-11018
  * Fixed leak and crashing issues:
  - gh#FreeRDP/FreeRDP#6129
  - gh#FreeRDP/FreeRDP#6128
  - gh#FreeRDP/FreeRDP#6127
  - gh#FreeRDP/FreeRDP#6110
  - gh#FreeRDP/FreeRDP#6081
  - gh#FreeRDP/FreeRDP#6077
  * Noteworthy features and improvements:
  - Fixed sound issues (gh#FreeRDP/FreeRDP#6043)
  - New expert command line options /tune and /tune-list to modify all client
    settings in a generic way.
  - Fixes for smartcard cache, this improves compatibility of smartcard devices
    with newer smartcard channel.
  - Shadow server can now be instructed to listen to multiple interfaces.
  - Improved server certificate support (gh#FreeRDP/FreeRDP#6052)
  - Various fixes for wayland client (fullscreen, mouse wheel, ...)
  - Fixed large mouse pointer support, now mouse pointers > 96x96 pixel are visible.
  - USB redirection command line improvements (filter options)
  - Various translation improvements for android and ios clients
- Removed upstream patches fix-freerdp-2.0.0-usbdk-build.patch
  and fix-URBDRC_DEVICE_ADD_FLAG-definitions.patch
* Fri Apr 17 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated and reviewed make command and added fix-freerdp-2.0.0-usbdk-build.patch
  to fix boo#1169679 and make USB working again
- Fixed build for SLE_12
- Cleaned up spec file
* Fri Apr 17 2020 Martin Liška <mliska@suse.cz>
- Add fix-URBDRC_DEVICE_ADD_FLAG-definitions.patch in order
  to fix boo#1169748.
* Mon Apr 13 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added cairo support for scaling
- Cleaned up spec
* Sun Apr 12 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Removed patch freerdp-Fix-realloc-return-handling.patch
- Added pkgconfig(libusb-1.0) for building
- Added new package for freerdp-proxy
- Cleaned up spec file
- Updated to release 2.0.0
  * Fixed CVEs:
  - CVE-2020-11521
  - CVE-2020-11522
  - CVE-2020-11523
  - CVE-2020-11524
  - CVE-2020-11525
  - CVE-2020-11526
  * Fixed security related issues:
  - gh#FreeRDP/FreeRDP#6005
  - gh#FreeRDP/FreeRDP#6006
  - gh#FreeRDP/FreeRDP#6007
  - gh#FreeRDP/FreeRDP#6008
  - gh#FreeRDP/FreeRDP#6009
  - gh#FreeRDP/FreeRDP#6010
  - gh#FreeRDP/FreeRDP#6011
  - gh#FreeRDP/FreeRDP#6012
  - gh#FreeRDP/FreeRDP#6013
  * sha256 is now used instead of sha1 to fingerprint certificates. This will
    invalidate all hosts in FreeRDP known_hosts2 file and causes a prompt if a
    new connection is established after the update
  * First version of the RDP proxy was added (gh#FreeRDP/FreeRDP#5372)
    thanks to @kubistika
  * Smartcard received some refactoring. Missing functions were added and input
    validation was improved (gh#FreeRDP/FreeRDP#5884)
  * A new option /cert that unifies all certificate related options (gh#FreeRDP/FreeRDP#5880)
    The old options (cert-ignore, cert-deny, cert-name, cert-tofu) are still
    available but marked as deprecated
  * Support for Remote Assistance Protocol Version 2 [MS-RA]
  * The DirectFB client was removed because it was unmaintained
  * Unified initialization of OrderSupport
  * Fix for licensing against Windows Server 2003
  * Font smoothing is now enabled per default
  * Smart scaling for Wayland using libcairo was added (gh#FreeRDP/FreeRDP#5215)
  * Unified update->BeginPaint and update->EndPaint
  * An image scaling API for software drawing was added
  * Rail was updated to the latest spec version 28.0
  * Support for H.264 in the shadow server is now detected at runtime
  * Add mask=<value> option for /gfx and /gfx-h264  (gh#FreeRDP/FreeRDP#5771)
  * A new option /timeout was added to adjust the TCP ACK timeout (gh#FreeRDP/FreeRDP#5987)
* Fri Mar 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO on aarch64 and %%arm to fix build
* Mon Oct 28 2019 Felix Zhang <fezhang@suse.com>
- Add freerdp-Fix-realloc-return-handling.patch: Fix realloc return
  handling that results in memory leaks (boo#1153163, boo#1153164,
  gh#FreeRDP/FreeRDP#5645, CVE-2019-17177, CVE-2019-17178)
* Wed Apr 17 2019 Felix Zhang <fezhang@suse.com>
- Add Requires: lib%%{name}%%{major_version} = %%{version}-%%{release}:
  freerdp should depend on the same release of libfreerdp2
  (boo#1129193)
* Tue Nov 20 2018 jweberhofer@weberhofer.at
- upgrade to version 2.0.0-rc4 (FATE#326739)
  * Fix the following issues:
  - CVE-2018-8784, boo#1116708
  - CVE-2018-8785, boo#1117967
  - CVE-2018-8786, boo#1117966
  - CVE-2018-8787, boo#1117964
  - CVE-2018-8788, boo#1117963
  - CVE-2018-8789, boo#1117965
  - CVE-2018-1000852, boo#1120507
  * Security and stability improvements, including boo#1103557 and boo#1112028
  * Refactored ntlm_av_pairs API
  * gateway: multiple fixes and improvements
  * client/X11: support for rail (remote app) icons was added
  * the licensing code was re-worked: Per-device licenses are now saved on the
    client and used on re-connect: WARNING: this is a change in FreeRDP
    behavior regarding licensing
    WARNING: this is a change in FreeRDP behavior regarding licensing. If the old
    behavior is required, or no licenses should be saved use the
    new command line option +old-license (gh#/FreeRDP/FreeRDP#4979)
  * improve order handling -  only orders that were enabled
    during capability exchange are accepted.
    WARNING and NOTE: some servers do improperly send orders that weren't negotiated,
    for such cases the new command line option /relax-order-checks was added to
    disable the strict order checking. If connecting to xrdp the options
    /relax-order-checks *and* +glyph-cache are required. (gh#/FreeRDP/FreeRDP#4926)
  * /smartcard has now support for substring filters (gh#/FreeRDP/FreeRDP#4840)
    for details see https://github.com/FreeRDP/FreeRDP/wiki/smartcard-logon
  * add new command line option /smartcard-logon to allow
    smartcard login (currently only with RDP security)
  * add support to set tls security level (for openssl >= 1.1.0)
  - default level is set to 1
  - the new command line option /tls-seclevel:[LEVEL] allows to set
    a different level if required
  * new command line option: /window-position to allow positioning
    the window on startup
  * client/X11: set window title before mapping
  * rdpsnd/audin (mostly server side) add support for audio re-sampling using soxr or ffmpeg
* Wed Aug  8 2018 jweberhofer@weberhofer.at
- upgrade to version 2.0.0-rc3
  See: https://github.com/FreeRDP/FreeRDP/milestone/9?closed=1
  * Improved and cleaned up the command line interface
  * Fixed automount issues
  * Fixed several audio and microphone related issues
  * Implemented AAC and MP3 codecs
  * Added Wave2 support
  * Addedd dynamic resolution with full screen toggle support
  * Improved redirection handling and certificate issues
  * Improved automatic reconnects
  * Improced connection error handling
  * Fixed invalid pointer, double-free, integer underflow,
    buffer overflows issues as well as other memory leaks
  * fixed X11 Right-Ctrl ungrab feature
  * winpr: Updates time zone data to April 2018
  * added libressl compatibility
* Mon May 14 2018 jweberhofer@weberhofer.at
- removed SLE11 condition
- removed no_connection_to_windows_10_17101.patch
- removed -DBUILTIN_CHANNELS=OFF switch
- explicitly set -DCHANNEL_GEOMETRY=ON
- Disable the new X264 and OPENH264 codecs because openSUSE does
  not provide them
- upgrade to version 2.0.0-rc2
  See: https://github.com/FreeRDP/FreeRDP/milestone/8
  Noteworthy features and improvements:
  * IMPORTANT: add support CredSSP v6 - this fixes KB4088776 see #4449, #4488
  * basic support for the "Video Optimized Remoting Virtual Channel
    Extension" (MS-RDPEVOR) was added
  * many smart card related fixes and cleanups #4312
  * fix ccache support
  * add support for memory and thread sanitizer
  * support for dynamic resloution changes was added in xfreerdp #4313
  * support for gateway access token (command line option /gat) was added
  * initial support for travis-ci.org was added
  * SSE optimization version of RGB to AVC444 frame split was added
  * build: -msse2/-msse3 are not enabled globally anymore
  Fixed github issues (excerpt):
  * #4227 Convert settings->Password to binary blob
  * #4231 freerdp-2.0.0_rc0: 5 tests failed out of 184 on ppc
  * #4276 Big endian fixes
  * #4291 xfreerdp “Segmentation fault” when connecting to freerdp-shadow-cli
  * #4293 [X11] shadow server memory corruption with /monitors:2 #4293
  * #4296 drive redirection - raise an error if the directory can't be found
  * #4306 Cannot connect to shadow server with NLA auth:
    SEC_E_OUT_OF_SEQUENCE (boo#1085416, boo#1087240, boo#1104918,
    CVE-2018-0886)
  * #4457 Fix /size: /w: /h: with /monitors: (Fix custom sizes)
  * #4527 pre-connection blob (pcb) support in .rdp files
  * #4552 Fix Windows 10 cursors drawing as black
  * smartcard related: #3521, #3431, #3474, #3488, #775, #1424
* Tue Apr 24 2018 bruno@ioda-net.ch
- Fix boo#1090677 activate pulse optional component
* Thu Mar 15 2018 jweberhofer@weberhofer.at
- Added no_connection_to_windows_10_17101.patch to fix
  Windows-connection-problem after Windows march 2018 updates.
  This fix is related to boo#1085416
* Mon Mar 12 2018 crrodriguez@opensuse.org
- Do not use xorg-x11-devel, instead buildrequire individual
  x components.
- Only attempt to ge rid of __DATE__ and __TIME__ if
  SOURCE_DATE_EPOCH is not set.
* Thu Jan 11 2018 jweberhofer@weberhofer.at
- Users can connect only once wo windows sessions due to
  [#]gh/FreeRDP/FreeRDP/4348
  Therefore WITH_GSSAPI has been disabled until that issue has been
  solved
* Thu Nov 30 2017 jweberhofer@weberhofer.at
- Updated to 2.0.0-rc1
  Noteworthy features and improvements:
  * support for FIPS mode was added (option +fipsmode)
  * initial client side kerberos support (run cmake with WITH_GSSAPI)
  * support for ssh-agent redirection (as rdp channel)
  * the man page(s) and /help were updated an improved
  * add support for ICU for unicode conversion (-DWITH_ICU=ON)
  * client add option to force password prompt before connection (/from-stdin[:force])
  * extend /size to allow width or height percentages (#gh/FreeRDP/FreeRDP/4146)
  * add support for "password is pin"
  * clipboard is now enabled per default (use -clipboard to disable)
  Fixed github issues (excerpt):
  * #gh/FreeRDP/FreeRDP/4281: Added option to prefer IPv6 over IPv4
  * #gh/FreeRDP/FreeRDP/3890: Point to OpenSSL doc for private CA
  * #gh/FreeRDP/FreeRDP/3378: support 31 static channels as described in the spec
  * #gh/FreeRDP/FreeRDP/4253: Rfx decode tile width.
  * #gh/FreeRDP/FreeRDP/3267: fix parsing of drivestoredirect
  * #gh/FreeRDP/FreeRDP/4257: Proper error checks for /kbd argument
  * #gh/FreeRDP/FreeRDP/4249: Corruption due to recursive parser
  * #gh/FreeRDP/FreeRDP/4111: 15bpp color handling for brush.
  * #gh/FreeRDP/FreeRDP/3509: Added Ctrl+Alt+Enter description
  * #gh/FreeRDP/FreeRDP/3211: Return freerdp error from main.
  * #gh/FreeRDP/FreeRDP/3513: add better description for drive redirection
  * #gh/FreeRDP/FreeRDP/4199: ConvertFindDataAToW string length
  * #gh/FreeRDP/FreeRDP/4135: client/x11: fix colors on big endian
  * #gh/FreeRDP/FreeRDP/4089: fix h264 context leak when DeleteSurface
  * #gh/FreeRDP/FreeRDP/4117: possible segfault
  * #gh/FreeRDP/FreeRDP/4091: fix a regression with remote program
* Mon Sep  4 2017 jengelh@inai.de
- Remove extraneous Obsoletes for packages that never existed
  in openSUSE:Factory or X11:RemoteDesktop.
- Rename libuwac0-devel to uwac0-devel and libwinpr-devel to
  winpr-devel, as that seems to be their upstream name which
  packages are encouraged to stick to.
- Remove duplicated pkgconfig requires (these are autodetected).
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Fixed download location
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Switched to official RC0
- Create wayland client package and libuwac0 package
- Create separate libwinpr2 to be used in other packages
- enabled gstreamer (currently disabled for tumbleweed)
- enabled kerberos authentication
- Update to official RC0
  Fix the following issues identified by the CISCO TALOS project:
  * TALOS-2017-0336 CVE-2017-2834 boo#1050714
  * TALOS-2017-0337 CVE-2017-2835 boo#1050712
  * TALOS-2017-0338 CVE-2017-2836 boo#1050699
  * TALOS-2017-0339 CVE-2017-2837 boo#1050704
  * TALOS-2017-0340 CVE-2017-2838 boo#1050708
  * TALOS-2017-0341 CVE-2017-2839 boo#1050711
* Sun Jun 11 2017 bruno@ioda-net.ch
- Redo history by using changelog url
- Update to version 2.0.0~git.1497095982.1dbd2d28d:
  See https://github.com/freerdp/freeRDP/compare/043243f...1dbd2d28d
  for full details.
- Packaging :
  + Move to xz tarball in _service
  + Remove 3472.patch merged upstream
- Update to version 2.0.0~git.1496304402.c42ccb508:
  See https://github.com/freerdp/freeRDP/compare/043243f...c42ccb508
  for changes.
* Sat Jun 10 2017 meissner@suse.com
- Forcefully enable PIE in CFLAGS as the automatism did not work.
* Tue Jan 17 2017 bruno@ioda-net.ch
- Add 3472.patch until upstream #3472 isssue is fixed and PR merged
  this fix boo#1004108
* Wed Oct 26 2016 dimstar@opensuse.org
- Update to version 2.0.0~git.1477034991.043243f:
  * fixed kerberos authentication
  * shadow/rdpsnd: Fix race condition in rdpsnd channel server.
    The output buffer and format parameters are not protected.
  * wfreerdp: fix invalid VerifyCertificate callback
  * rdpsnd/server: decrease audio latency and make it configurable.
  * Add an environment variables section to the man
  * protocol violation: rdp_read_extended_info_packet
  * Added support for OpenH264 1.6
  * freerdp: fix sending of TLS alert on NLA failure, add better
    handling of server-side NLA in shadow server
  * freerdp: add configurable NTLM SAM file option for
    server-side NLA
  * freerdp: make modifications to NLA server-side fixes according
    to PR comments
  * Fixed a windows 8.1 issue.
* Wed May 18 2016 jengelh@inai.de
- Kill off __DATE__ from built sources.
* Tue May 17 2016 fezhang@suse.com
- Update to GNOME 3.20.2 FATE#318572
- Add obs git integration.
- Update to version 2.0.0git.1463131968.4e66df7:
  + Fixed memory leaks.
  + wfreerdp: fix name build without client interface
  + libfreerdp-codec: fix xcrush decompression, revert remote
    control fix
  + KB3153731: May 2016 DST update for Azerbaijan, Chile, Haiti and
    Morocco
  + libfreerdp-codec: make proper xcrush context reset fix
* Wed May  4 2016 fezhang@suse.com
- Update to version 2.0.0, git master branch id a7ca42e
  (FATE#319661), no upstream changelog available.
  * Warning: This is a git snapshot regarded as technical preview
    by upstream.
  * Warning: For xfreerdp, new /long-option commandline interfaces
    have replaced the old --long-option interfaces. Existing user
    scripts need to migrate to the new interfaces to avoid
    breakages.
    For more details, see:
    https://github.com/FreeRDP/FreeRDP/wiki/CommandLineInterface
  * Add Network Level Ahthentication support.
  * Add Windows Portable Runtime. For more details, see:
    http://www.freerdp.com/2012/05/24/winpr-windows-portable-runtime
  * Obsolete libfreerdp-1_0-plugins.
- Drop FindALSA.cmake: deprecated
- Drop freerdp_branch-1.0.x_fix-kpdivide-issue831.patch:
  fixed upstream, implemention now in include/freerdp/scancode.h.
- Drop freerdp-CVE-2014-0250.patch (bnc#880317):
  fixed upstream 532c420.
- Drop freerdp-CVE-2014-0791.patch (bnc#857491):
  fixed upstream f1d6afc.
- Drop freerdp-fix-FindPCSC-macro.patch:
  fixed upstream 9148af3.
- Drop freerdp-handle-null-device-name.patch (bnc#785437):
  deprecated, related implementation dropped.
  was: freerdp-fix-pulse-no-device-name.patch
* Mon Jun 23 2014 fezhang@suse.com
- Add freerdp-CVE-2014-0791.patch to fix bnc#857491
  backported from upstream commit f1d6afc
* Thu Jun 12 2014 dliang@suse.com
- Add freerdp-CVE-2014-0250.patch to fix bnc#880317
  solves CVE-2014-0250, backport from upstream
* Thu Oct 31 2013 lnt-sysadmin@lists.lrz.de
- Allow build on SLES11:
  * converted pkgconfig() BuildRequires to package names
  * added FindALSA.cmake
  * use 'make install' instead of '%%make_install' macro
* Thu Sep 12 2013 crrodriguez@opensuse.org
- build with -DOPENSSL_LOAD_CONF so among other things
  the application respects the system's openSSL configuration.
* Thu Mar  7 2013 bruno@ioda-net.ch
- Added patch for issue #811 fixing divide key (/) on keypad for
  1.0x series,
  commit https://github.com/bmiklautz/FreeRDP/commit/e0cc1e60657b5883a907e5da2f70eb27bf0b91f1
- Added changelog
  FreeRDP 1.0.2 is a maintenance release which contains several bug
  and stability fixes.
  * xfreerdp:
  * new parameter --from-stdin - prompts for unspecified arguments
    username, password, domain and host.
  * fix compability with x2go
  * fix keyboard state in remote app
  * documentation fixes
  * fixed crash when started with --authonly (#843)
  * libfreerdp-core:
  * several memory leaks and double frees were fixed
  * support for FastPath PDUs up to 32767
  * register audio only if plugin is registered
  * load extensions after argument parsing
  * libfreerdp-utils:
  * fixed crash when HOME environment variable wasn't set
  * xfreerdp-server:
  * deadlock fixed
  * accept TLSv1 and SSLv3
  * smartcard:
  * don't incorrectly set SCARD_STATE_IGNORE
  * libfreerdp-codec:
  * performance improvement
  * libfreerdp-gdi:
  * support for PatBlt DPa operation
  * plugin:
  * ignore CHANNEL_FLAG_SUSPEND/CHANNEL_FLAG_RESUME to prevent
    possible crash
  For a detailed list of changes use "git log 1.0.1..1.0.2"
  known problems:
  * If windows input language is set to german pressing the divde
    key (/) on the keypad results in minus (-) (see issue #811)
* Thu Jan 24 2013 kkaempf@suse.com
- update to 1.0.2
  - bugfix release (no changelog posted)
  - drop patches that are upstream
* Fri Dec 28 2012 dmueller@suse.com
- only enable SSE2 on x86*
* Fri Dec 28 2012 dvaleev@suse.com
- disable SSE2 for ARM as well
* Fri Dec 28 2012 dvaleev@suse.com
- disable SSE2 for powerpc
* Thu Dec 27 2012 gber@opensuse.org
- build with WITH_SSE2=ON as freerdp now uses runtime detection
  (bnc#793611)
* Thu Nov  1 2012 gber@opensuse.org
- added freerdp-fix-pulse-no-device-name.patch in order to fix a
  segfault in case device name is not provided (bnc#785437)
* Wed Oct 17 2012 gber@opensuse.org
- added freerdp-fix-linking-with-libpulse.patch in order to link
  correctly with libpulse
  (https://github.com/FreeRDP/FreeRDP/issues/418, bnc#785437)
* Sun Apr 29 2012 zawertun@gmail.com
- added freerdp-fix-incorrect-numlock-state.patch which fixes
  incorrect num lock state when connecting
  (https://github.com/FreeRDP/FreeRDP/pull/564)
* Sun Apr 22 2012 gber@opensuse.org
- added freerdp-fix-FindPCSC-macro.patch which fixes the build by
  setting PCSC_LIBRARIES and PCSC_INCLUDE_DIRS variables explicitly
  which are otherwise empty
  (https://github.com/FreeRDP/FreeRDP/issues/562)
* Thu Apr 19 2012 gber@opensuse.org
- applied fix for a bug in freerdp-fix-bitmap-cache.patch from
  upstream git
* Fri Mar 30 2012 zawertun@gmail.com
- added freerdp-fix-bitmap-cache.patch fixing a problem with the
  bitmap cache resulting in garbled images
  (https://github.com/FreeRDP/FreeRDP/issues/348)
* Wed Mar 28 2012 gber@opensuse.org
- split off -plugins subpackage
- specfile cleanup
* Tue Mar  6 2012 gankov@opensuse.org
- rewrote spec for using cmake.
- update to version 1.0.1
  - FreeRDP 1.x series is a complete rewrite now licensed under
    the Apache License 2.0
  - RemoteFX
  - Both encoder and decoder
  - SSE2 and NEON optimization
  - NSCodec
  - RemoteApp
  - Working, minor glitches
  - Multimedia Redirection
  - ffmpeg support
  - Network Level Authentication (NLA)
  - NTLMv2
  - Certificate validation
  - FIPS-compliant RDP security
  - new build system (cmake)
  - added official logo and icon
* Fri Dec  2 2011 gber@opensuse.org
- add explicit dependency on libtool
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep 22 2011 gber@opensuse.org
- cleanup to comply with the packaging policy
  - add header
  - use the correct license format
  - remove %%clean section
  - simplify the manipulation of PLUGIN_PATH
  - remove %%debug_package
  - add meaningful description
  - do not recompres the source tarball any more
  - corrected URLs
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- fix bnc#688484 by passing --with-sound=alsa and alsa-devel in
  BuildRequires
* Wed Nov 17 2010 pascal.bleser@opensuse.org
- rewrote most of the spec file (wrong group, wrong subpackages,
  ldconfig called on devel package, shlibs inj devel package, ...)
- update to 0.8.2:
  * libfreerdp:
    + fix buffer overflow when local timezone doesn't fit in 32
    bytes
    + fix data corruption after TLS license package
    + free TLS resources to avoid memory leaks
  * mcs:
    + fix connecting to VirtualBox with extra channels
  * rdpsnd plugin:
    + ensure the ALSA device is closed when freeing resources
  * rdpdr plugin:
    + fix various memory leaks
    + fix a segfault in multi-session environment
* Wed Oct 27 2010 hrustov@gmail.com
- initial build
